@@ -1,7 +1,14 @@
 import unittest
 from test import support
+from test.support import warnings_helper
 import os
 import sys
+import types
+
+try:
+    import _multiprocessing
+except ModuleNotFoundError:
+    _multiprocessing = None
 
 
 if support.check_sanitizer(address=True, memory=True):
@@ -20,9 +27,21 @@ class FailedImport(RuntimeError):
 
 class AllTest(unittest.TestCase):
 
+    def setUp(self):
+        # concurrent.futures uses a __getattr__ hook. Its __all__ triggers
+        # import of a submodule, which fails when _multiprocessing is not
+        # available.
+        if _multiprocessing is None:
+            sys.modules["_multiprocessing"] = types.ModuleType("_multiprocessing")
+
+    def tearDown(self):
+        if _multiprocessing is None:
+            sys.modules.pop("_multiprocessing")
+
     def check_all(self, modname):
         names = {}
-        with support.check_warnings(
+        with warnings_helper.check_warnings(
+            (f".*{modname}", DeprecationWarning),
             (".* (module|package)", DeprecationWarning),
             (".* (module|package)", PendingDeprecationWarning),
             ("", ResourceWarning),
@@ -38,7 +57,7 @@ class AllTest(unittest.TestCase):
             raise NoAll(modname)
         names = {}
         with self.subTest(module=modname):
-            with support.check_warnings(
+            with warnings_helper.check_warnings(
                 ("", DeprecationWarning),
                 ("", ResourceWarning),
                 quiet=True):
@@ -61,6 +80,12 @@ class AllTest(unittest.TestCase):
                 self.assertEqual(keys, all_set, "in module {}".format(modname))
 
     def walk_modules(self, basedir, modpath):
+        if modpath == 'distutils.':
+            # gh-135374: when setuptools is installed, it now replaces
+            # 'distutils' with its own version.
+            # In a security-fix only branch of CPython,
+            # skip the __all__ test rather than deal with the fallout.
+            return
         for fn in sorted(os.listdir(basedir)):
             path = os.path.join(basedir, fn)
             if os.path.isdir(path):
@@ -75,8 +100,8 @@ class AllTest(unittest.TestCase):
             yield path, modpath + fn[:-3]
 
     def test_all(self):
-        # Blacklisted modules and packages
-        blacklist = set([
+        # List of denied modules and packages
+        denylist = set([
             # Will raise a SyntaxError when compiling the exec statement
             '__future__',
         ])
@@ -91,13 +116,13 @@ class AllTest(unittest.TestCase):
         lib_dir = os.path.dirname(os.path.dirname(__file__))
         for path, modname in self.walk_modules(lib_dir, ""):
             m = modname
-            blacklisted = False
+            denied = False
             while m:
-                if m in blacklist:
-                    blacklisted = True
+                if m in denylist:
+                    denied = True
                     break
                 m = m.rpartition('.')[0]
-            if blacklisted:
+            if denied:
                 continue
             if support.verbose:
                 print(modname)
